@@ -26,16 +26,16 @@
 #include <tqregexp.h>
 #include <tqdir.h>
 
-#include <kfileitem.h>
+#include <tdefileitem.h>
 #include <kdebug.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kinstance.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kurl.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 #include <klargefile.h>
 #include <kstandarddirs.h>
-#include <kio/job.h>
+#include <tdeio/job.h>
 #include <ktar.h>
 
 #include <iostream>
@@ -57,18 +57,18 @@
 #define KRDEBUG(X...)
 #endif
 
-using namespace KIO;
+using namespace TDEIO;
 extern "C" {
 
 int kdemain( int argc, char **argv ){
-	KInstance instance( "kio_krarc" );
+	TDEInstance instance( "tdeio_krarc" );
 	
 	if (argc != 4) {
-		kdWarning() << "Usage: kio_krarc  protocol domain-socket1 domain-socket2" << endl;
+		kdWarning() << "Usage: tdeio_krarc  protocol domain-socket1 domain-socket2" << endl;
 		exit(-1);
 	}
 	
-	kio_krarcProtocol slave(argv[2], argv[3]);
+	tdeio_krarcProtocol slave(argv[2], argv[3]);
 	slave.dispatchLoop();
 	
 	return 0;
@@ -76,11 +76,11 @@ int kdemain( int argc, char **argv ){
 
 } // extern "C" 
 
-kio_krarcProtocol::kio_krarcProtocol(const TQCString &pool_socket, const TQCString &app_socket)
-	: SlaveBase("kio_krarc", pool_socket, app_socket), archiveChanged(true), arcFile(0L),extArcReady(false),
+tdeio_krarcProtocol::tdeio_krarcProtocol(const TQCString &pool_socket, const TQCString &app_socket)
+	: SlaveBase("tdeio_krarc", pool_socket, app_socket), archiveChanged(true), arcFile(0L),extArcReady(false),
 		password(TQString()) {
 	
-	krConfig = new KConfig( "krusaderrc" );
+	krConfig = new TDEConfig( "krusaderrc" );
 	krConfig->setGroup( "Dependencies" );
 	
 	dirDict.setAutoDelete(true);
@@ -93,15 +93,15 @@ kio_krarcProtocol::kio_krarcProtocol(const TQCString &pool_socket, const TQCStri
 }
 
 /* ---------------------------------------------------------------------------------- */
-kio_krarcProtocol::~kio_krarcProtocol(){
+tdeio_krarcProtocol::~tdeio_krarcProtocol(){
 	// delete the temp directory
 	KrShellProcess proc;
 	proc << "rm -rf "<< arcTempDir;
-	proc.start(KProcess::Block);
+	proc.start(TDEProcess::Block);
 }
 
 /* ---------------------------------------------------------------------------------- */
-void kio_krarcProtocol::receivedData(KProcess*,char* buf,int len){
+void tdeio_krarcProtocol::receivedData(TDEProcess*,char* buf,int len){
 	TQByteArray d(len);
 	d.setRawData(buf,len);
 	data(d);
@@ -110,7 +110,7 @@ void kio_krarcProtocol::receivedData(KProcess*,char* buf,int len){
 	decompressedLen += len;
 }
 
-void kio_krarcProtocol::mkdir(const KURL& url,int permissions){
+void tdeio_krarcProtocol::mkdir(const KURL& url,int permissions){
 	KRDEBUG(url.path());
 	
 	if( !setArcFile( url ) ) {
@@ -156,7 +156,7 @@ void kio_krarcProtocol::mkdir(const KURL& url,int permissions){
 	proc << putCmd << convertName( arcFile->url().path() ) + " " << convertFileName( tmpDir.mid(arcTempDir.length()) );
 	infoMessage(i18n("Creating %1 ...").arg( url.fileName() ) );
 	TQDir::setCurrent(arcTempDir);
-	proc.start(KProcess::Block,KProcess::AllOutput);
+	proc.start(TDEProcess::Block,TDEProcess::AllOutput);
 	
 	// delete the temp directory
 	TQDir().rmdir(arcTempDir);
@@ -171,7 +171,7 @@ void kio_krarcProtocol::mkdir(const KURL& url,int permissions){
 	finished();
 }
 
-void kio_krarcProtocol::put(const KURL& url,int permissions,bool overwrite,bool resume){
+void tdeio_krarcProtocol::put(const KURL& url,int permissions,bool overwrite,bool resume){
 	KRDEBUG(url.path());
 	if( !setArcFile( url ) ) {
 		error(ERR_CANNOT_ENTER_DIRECTORY,url.path());
@@ -227,7 +227,7 @@ void kio_krarcProtocol::put(const KURL& url,int permissions,bool overwrite,bool
 	proc << putCmd << convertName( arcFile->url().path() )+ " " <<convertFileName( tmpFile.mid(arcTempDir.length()) );
 	infoMessage(i18n("Packing %1 ...").arg( url.fileName() ) );
 	TQDir::setCurrent(arcTempDir);
-	proc.start(KProcess::Block,KProcess::AllOutput);
+	proc.start(TDEProcess::Block,TDEProcess::AllOutput);
 	// remove the file
 	TQFile::remove(tmpFile);
 
@@ -240,11 +240,11 @@ void kio_krarcProtocol::put(const KURL& url,int permissions,bool overwrite,bool
 	finished();
 }
 
-void kio_krarcProtocol::get(const KURL& url ){
+void tdeio_krarcProtocol::get(const KURL& url ){
 	get( url, TRIES_WITH_PASSWORDS );
 }
 
-void kio_krarcProtocol::get(const KURL& url, int tries ){
+void tdeio_krarcProtocol::get(const KURL& url, int tries ){
 	bool decompressToFile = false;
 	KRDEBUG(url.path());
 	
@@ -264,19 +264,19 @@ void kio_krarcProtocol::get(const KURL& url, int tries ){
 	} 
 	UDSEntry* entry = findFileEntry(url);
 	if( !entry ){
-		error(KIO::ERR_DOES_NOT_EXIST,url.path());
+		error(TDEIO::ERR_DOES_NOT_EXIST,url.path());
 		return;
 	}
 	if(KFileItem(*entry,url).isDir()){
-		error(KIO::ERR_IS_DIRECTORY,url.path());
+		error(TDEIO::ERR_IS_DIRECTORY,url.path());
 		return;
 	}
-	KIO::filesize_t expectedSize = KFileItem(*entry,url).size();
+	TDEIO::filesize_t expectedSize = KFileItem(*entry,url).size();
 	// for RPM files extract the cpio file first
 	if( !extArcReady && arcType == "rpm"){
 		KrShellProcess cpio;
 		cpio << "rpm2cpio" << convertName( arcFile->url().path(-1) ) << " > " << arcTempDir+"contents.cpio";
-		cpio.start(KProcess::Block,KProcess::AllOutput);
+		cpio.start(TDEProcess::Block,TDEProcess::AllOutput);
 		if( !cpio.normalExit() || cpio.exitStatus() != 0 )  {
 			error(ERR_COULD_NOT_READ,url.path() + "\n\n" + cpio.getErrorMsg() );
 			return;
@@ -287,7 +287,7 @@ void kio_krarcProtocol::get(const KURL& url, int tries ){
 	if ( !extArcReady && arcType == "deb" ) {
 		KrShellProcess dpkg;
 		dpkg << cmd + " --fsys-tarfile" << convertName( arcFile->url().path( -1 ) ) << " > " << arcTempDir + "contents.cpio";
-		dpkg.start( KProcess::Block, KProcess::AllOutput );
+		dpkg.start( TDEProcess::Block, TDEProcess::AllOutput );
 		if( !dpkg.normalExit() || dpkg.exitStatus() != 0 )  {
 			error(ERR_COULD_NOT_READ,url.path() + "\n\n" + dpkg.getErrorMsg() );
 			return;
@@ -314,13 +314,13 @@ void kio_krarcProtocol::get(const KURL& url, int tries ){
 		emit mimeType( mt->name() );
 		proc << getCmd << convertName( arcFile->url().path() )+" ";
 		if( arcType != "gzip" && arcType != "bzip2" ) proc << convertFileName( file );
-		connect(&proc,TQT_SIGNAL(receivedStdout(KProcess*,char*,int)),
-				this,TQT_SLOT(receivedData(KProcess*,char*,int)) );
+		connect(&proc,TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
+				this,TQT_SLOT(receivedData(TDEProcess*,char*,int)) );
 	}
 	infoMessage(i18n("Unpacking %1 ...").arg( url.fileName() ) );
 	// change the working directory to our arcTempDir
 	TQDir::setCurrent(arcTempDir);
-	proc.start(KProcess::Block,KProcess::AllOutput);
+	proc.start(TDEProcess::Block,TDEProcess::AllOutput);
 	
 	if( !extArcReady && !decompressToFile ) {  
 		if( !proc.normalExit() || !checkStatus( proc.exitStatus() ) || ( arcType != "bzip2" && expectedSize != decompressedLen ) ) {
@@ -329,7 +329,7 @@ void kio_krarcProtocol::get(const KURL& url, int tries ){
 				get( url, tries - 1 );
 				return;
 			}
-			error( KIO::ERR_ACCESS_DENIED, url.path() + "\n\n" + proc.getErrorMsg() );
+			error( TDEIO::ERR_ACCESS_DENIED, url.path() + "\n\n" + proc.getErrorMsg() );
 			return;
 		}
 	}
@@ -342,31 +342,31 @@ void kio_krarcProtocol::get(const KURL& url, int tries ){
 				get( url, tries - 1 );
 				return;
 			}
-			error( KIO::ERR_ACCESS_DENIED, url.path() );
+			error( TDEIO::ERR_ACCESS_DENIED, url.path() );
 			return;
 		}
-		// the follwing block is ripped from KDE file KIO::Slave
+		// the follwing block is ripped from KDE file TDEIO::Slave
 		// $Id: krarc.cpp,v 1.43 2007/01/13 13:39:51 ckarai Exp $
 		TQCString _path( TQFile::encodeName(arcTempDir+file) );
 		KDE_struct_stat buff;
 		if( KDE_lstat( _path.data(), &buff ) == -1 ) {
 			if ( errno == EACCES )
-				error( KIO::ERR_ACCESS_DENIED, url.path() );
+				error( TDEIO::ERR_ACCESS_DENIED, url.path() );
 			else
-				error( KIO::ERR_DOES_NOT_EXIST, url.path() );
+				error( TDEIO::ERR_DOES_NOT_EXIST, url.path() );
 			return;
 		}
 		if ( S_ISDIR( buff.st_mode ) ) {
-			error( KIO::ERR_IS_DIRECTORY, url.path() );
+			error( TDEIO::ERR_IS_DIRECTORY, url.path() );
 			return;
 		}
 		if ( !S_ISREG(buff.st_mode) ) {
-			error( KIO::ERR_CANNOT_OPEN_FOR_READING, url.path() );
+			error( TDEIO::ERR_CANNOT_OPEN_FOR_READING, url.path() );
 			return;
 		}
 		int fd = KDE_open( _path.data(), O_RDONLY );
 		if ( fd < 0 ) {
-			error( KIO::ERR_CANNOT_OPEN_FOR_READING, url.path() );
+			error( TDEIO::ERR_CANNOT_OPEN_FOR_READING, url.path() );
 			return;
 		}
 		// Determine the mimetype of the file to be retrieved, and emit it.
@@ -374,12 +374,12 @@ void kio_krarcProtocol::get(const KURL& url, int tries ){
 		KMimeType::Ptr mt = KMimeType::findByURL( arcTempDir+file, buff.st_mode, true /* local URL */ );
 		emit mimeType( mt->name() );
 		
-		KIO::filesize_t processed_size = 0;
+		TDEIO::filesize_t processed_size = 0;
 		
 		TQString resumeOffset = metaData("resume");
 		if ( !resumeOffset.isEmpty() ){
 			bool ok;
-			KIO::fileoffset_t offset = resumeOffset.toLongLong(&ok);
+			TDEIO::fileoffset_t offset = resumeOffset.toLongLong(&ok);
 			if (ok && (offset > 0) && (offset < buff.st_size)){
 				if (KDE_lseek(fd, offset, SEEK_SET) == offset){
 					canResume ();
@@ -397,7 +397,7 @@ void kio_krarcProtocol::get(const KURL& url, int tries ){
 			if (n == -1){
 				if (errno == EINTR)
 					continue;
-				error( KIO::ERR_COULD_NOT_READ, url.path());
+				error( TDEIO::ERR_COULD_NOT_READ, url.path());
 				close(fd);
 				return;
 			}
@@ -425,7 +425,7 @@ void kio_krarcProtocol::get(const KURL& url, int tries ){
 	finished();
 }
 
-void kio_krarcProtocol::del(KURL const & url, bool isFile){
+void tdeio_krarcProtocol::del(KURL const & url, bool isFile){
 	KRDEBUG(url.path());
 	
 	if( !setArcFile( url ) ) {
@@ -444,7 +444,7 @@ void kio_krarcProtocol::del(KURL const & url, bool isFile){
 	}
 	if( !findFileEntry(url) ){
 		if( ( arcType != "arj" && arcType != "lha" ) || isFile ) {
-			error(KIO::ERR_DOES_NOT_EXIST,url.path());
+			error(TDEIO::ERR_DOES_NOT_EXIST,url.path());
 			return;
 		}
 	}
@@ -456,7 +456,7 @@ void kio_krarcProtocol::del(KURL const & url, bool isFile){
 	KrShellProcess proc;
 	proc << delCmd << convertName( arcFile->url().path() )+" " << convertFileName( file );
 	infoMessage(i18n("Deleting %1 ...").arg( url.fileName() ) );
-	proc.start(KProcess::Block, KProcess::AllOutput);
+	proc.start(TDEProcess::Block, TDEProcess::AllOutput);
 	if( !proc.normalExit() || !checkStatus( proc.exitStatus() ) )  {
 		error(ERR_COULD_NOT_WRITE,url.path() + "\n\n" + proc.getErrorMsg() );
 		return;
@@ -466,7 +466,7 @@ void kio_krarcProtocol::del(KURL const & url, bool isFile){
 	finished();
 }
 
-void kio_krarcProtocol::stat( const KURL & url ){  
+void tdeio_krarcProtocol::stat( const KURL & url ){  
 	KRDEBUG(url.path());
 	if( !setArcFile( url ) ) {
 		error(ERR_CANNOT_ENTER_DIRECTORY,url.path());
@@ -503,10 +503,10 @@ void kio_krarcProtocol::stat( const KURL & url ){
 	if( entry ){
 		statEntry( *entry );
 		finished();
-	} else error( KIO::ERR_DOES_NOT_EXIST, path );
+	} else error( TDEIO::ERR_DOES_NOT_EXIST, path );
 }
 
-void kio_krarcProtocol::copy (const KURL &url, const KURL &dest, int, bool overwrite) {
+void tdeio_krarcProtocol::copy (const KURL &url, const KURL &dest, int, bool overwrite) {
 	KRDEBUG(url.path());
   
 	// KDE HACK: opening the password dlg in copy causes error for the COPY, and further problems
@@ -552,13 +552,13 @@ void kio_krarcProtocol::copy (const KURL &url, const KURL &dest, int, bool overw
 				proc << "<" << "/dev/ptmx"; 
 			
 			infoMessage(i18n("Unpacking %1 ...").arg( url.fileName() ) );
-			proc.start(KProcess::Block, KProcess::AllOutput);
+			proc.start(TDEProcess::Block, TDEProcess::AllOutput);
 			if( !proc.normalExit() || !checkStatus( proc.exitStatus() ) )  {
-				error(KIO::ERR_COULD_NOT_WRITE, dest.path(-1) + "\n\n" + proc.getErrorMsg() );
+				error(TDEIO::ERR_COULD_NOT_WRITE, dest.path(-1) + "\n\n" + proc.getErrorMsg() );
 				return;
 			}
 			if( !TQFileInfo( dest.path(-1) ).exists() ) {
-				error( KIO::ERR_COULD_NOT_WRITE, dest.path(-1) );
+				error( TDEIO::ERR_COULD_NOT_WRITE, dest.path(-1) );
 				return;
 			}
 			
@@ -571,7 +571,7 @@ void kio_krarcProtocol::copy (const KURL &url, const KURL &dest, int, bool overw
 	error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_COPY));
 }
 
-void kio_krarcProtocol::listDir(const KURL& url){
+void tdeio_krarcProtocol::listDir(const KURL& url){
 	KRDEBUG(url.path());
 	if( !setArcFile( url ) ) {
 		error(ERR_CANNOT_ENTER_DIRECTORY,url.path());
@@ -615,7 +615,7 @@ void kio_krarcProtocol::listDir(const KURL& url){
 	finished();
 }
 
-bool kio_krarcProtocol::setArcFile(const KURL& url){
+bool tdeio_krarcProtocol::setArcFile(const KURL& url){
 	TQString path = url.path();
 	time_t currTime = time( 0 );
 	archiveChanged = true;
@@ -690,7 +690,7 @@ bool kio_krarcProtocol::setArcFile(const KURL& url){
 	return initArcParameters();
 }
 
-bool kio_krarcProtocol::initDirDict(const KURL&url, bool forced){
+bool tdeio_krarcProtocol::initDirDict(const KURL&url, bool forced){
 	// set the archive location
 	//if( !setArcFile(url.path()) ) return false;
 	// no need to rescan the archive if it's not changed
@@ -711,7 +711,7 @@ bool kio_krarcProtocol::initDirDict(const KURL&url, bool forced){
 			proc << listCmd << convertName( arcFile->url().path(-1) ) <<" > " << temp.name();
 		if( arcType == "ace" && TQFile( "/dev/ptmx" ).exists() ) // Don't remove, unace crashes if missing!!!
 			proc << "<" << "/dev/ptmx";
-		proc.start(KProcess::Block,KProcess::AllOutput);
+		proc.start(TDEProcess::Block,TDEProcess::AllOutput);
 		if( !proc.normalExit() || !checkStatus( proc.exitStatus() ) ) return false;
 	}
 	// clear the dir dictionary
@@ -807,7 +807,7 @@ bool kio_krarcProtocol::initDirDict(const KURL&url, bool forced){
 	return true;
 }
 
-TQString kio_krarcProtocol::findArcDirectory(const KURL& url){
+TQString tdeio_krarcProtocol::findArcDirectory(const KURL& url){
 	TQString path = url.path();
 	if( path.right(1) == "/" ) path.truncate(path.length()-1);
 	
@@ -821,7 +821,7 @@ TQString kio_krarcProtocol::findArcDirectory(const KURL& url){
 	return arcDir;
 }
 
-UDSEntry* kio_krarcProtocol::findFileEntry(const KURL& url){
+UDSEntry* tdeio_krarcProtocol::findFileEntry(const KURL& url){
 	TQString arcDir = findArcDirectory(url);
 	if( arcDir.isEmpty() ) return 0;
 	
@@ -851,7 +851,7 @@ UDSEntry* kio_krarcProtocol::findFileEntry(const KURL& url){
 	return 0;
 }
 
-TQString kio_krarcProtocol::nextWord(TQString &s,char d) {
+TQString tdeio_krarcProtocol::nextWord(TQString &s,char d) {
 	s=s.stripWhiteSpace();
 	int j=s.find(d,0);
 	TQString temp=s.left(j); // find the leftmost word.
@@ -859,7 +859,7 @@ TQString kio_krarcProtocol::nextWord(TQString &s,char d) {
 	return temp;
 }
 
-mode_t kio_krarcProtocol::parsePermString(TQString perm){
+mode_t tdeio_krarcProtocol::parsePermString(TQString perm){
 	mode_t mode=0;
 	// file type
 	if(perm[0] == 'd') mode |= S_IFDIR;
@@ -881,7 +881,7 @@ mode_t kio_krarcProtocol::parsePermString(TQString perm){
 	return mode;
 }
 
-UDSEntryList* kio_krarcProtocol::addNewDir(TQString path){
+UDSEntryList* tdeio_krarcProtocol::addNewDir(TQString path){
 	UDSEntryList* dir;
 	
 	// check if the current dir exists
@@ -928,7 +928,7 @@ UDSEntryList* kio_krarcProtocol::addNewDir(TQString path){
 	return dir;
 }
 
-void kio_krarcProtocol::parseLine(int lineNo, TQString line, TQFile*) {
+void tdeio_krarcProtocol::parseLine(int lineNo, TQString line, TQFile*) {
 	UDSEntryList* dir;
 	UDSEntry entry;
 	UDSAtom atom;
@@ -1232,7 +1232,7 @@ void kio_krarcProtocol::parseLine(int lineNo, TQString line, TQFile*) {
 	dir->append(entry);
 }
 
-bool kio_krarcProtocol::initArcParameters() {
+bool tdeio_krarcProtocol::initArcParameters() {
 	KRDEBUG("arcType: "<<arcType);
 	
 	if(arcType == "zip"){
@@ -1241,7 +1241,7 @@ bool kio_krarcProtocol::initArcParameters() {
 		getCmd  = fullPathName( "unzip" ) + " -p ";
 		copyCmd = fullPathName( "unzip" ) + " -jo ";
 		
-		if( KStandardDirs::findExe( "zip" ).isEmpty() ) {
+		if( TDEStandardDirs::findExe( "zip" ).isEmpty() ) {
 			delCmd  = TQString();
 			putCmd  = TQString();
 		} else {
@@ -1255,7 +1255,7 @@ bool kio_krarcProtocol::initArcParameters() {
 			putCmd += "-P '"+password+"' ";
 		}
 	} else if (arcType == "rar") {
-		if( KStandardDirs::findExe( "rar" ).isEmpty() ) {
+		if( TDEStandardDirs::findExe( "rar" ).isEmpty() ) {
 			cmd     = fullPathName( "unrar" );
 			listCmd = fullPathName( "unrar" ) + " -c- -v v ";
 			getCmd  = fullPathName( "unrar" ) + " p -ierr -idp -c- -y ";
@@ -1339,7 +1339,7 @@ bool kio_krarcProtocol::initArcParameters() {
 		putCmd = TQString();	
 	} else if (arcType == "7z") {
 		cmd = fullPathName( "7z" );
-		if( KStandardDirs::findExe(cmd).isEmpty() )
+		if( TDEStandardDirs::findExe(cmd).isEmpty() )
 			cmd = fullPathName( "7za" );
 		
 		listCmd = cmd + " l -y ";
@@ -1366,8 +1366,8 @@ bool kio_krarcProtocol::initArcParameters() {
 		putCmd  = TQString();
 	}
 
-	if( KStandardDirs::findExe(cmd).isEmpty() ){
-		error( KIO::ERR_CANNOT_LAUNCH_PROCESS,
+	if( TDEStandardDirs::findExe(cmd).isEmpty() ){
+		error( TDEIO::ERR_CANNOT_LAUNCH_PROCESS,
 		cmd+
 		i18n("\nMake sure that the %1 binary are installed properly on your system.").arg(cmd));
 		KRDEBUG("Failed to find cmd: " << cmd);
@@ -1376,7 +1376,7 @@ bool kio_krarcProtocol::initArcParameters() {
 	return true;
 }
 
-bool kio_krarcProtocol::checkStatus( int exitCode ) {
+bool tdeio_krarcProtocol::checkStatus( int exitCode ) {
 	KRDEBUG( exitCode );
 	
 	if( arcType == "zip" || arcType == "rar" || arcType == "7z" )
@@ -1395,7 +1395,7 @@ struct AutoDetectParams {
 	TQString detectionString;
 };
 
-TQString kio_krarcProtocol::detectArchive( bool &encrypted, TQString fileName ) {
+TQString tdeio_krarcProtocol::detectArchive( bool &encrypted, TQString fileName ) {
 	static AutoDetectParams autoDetectParams[] = {{"zip",  0, "PK\x03\x04"},
 	                                              {"rar",  0, "Rar!\x1a" },
 	                                              {"arj",  0, "\x60\xea" },
@@ -1501,9 +1501,9 @@ TQString kio_krarcProtocol::detectArchive( bool &encrypted, TQString fileName )
 					else {  // we try to find whether the 7z archive is encrypted
 						// this is hard as the headers are also compresseds
 						TQString tester = fullPathName( "7z" );
-						if( KStandardDirs::findExe( tester ).isEmpty() ) {
+						if( TDEStandardDirs::findExe( tester ).isEmpty() ) {
 							tester = fullPathName( "7za" );
-							if( KStandardDirs::findExe( tester ).isEmpty() ) {
+							if( TDEStandardDirs::findExe( tester ).isEmpty() ) {
 								return type;
 							}
 						}
@@ -1513,9 +1513,9 @@ TQString kio_krarcProtocol::detectArchive( bool &encrypted, TQString fileName )
 						
 						KrShellProcess proc;
 						proc << testCmd << convertName( fileName );
-						connect( &proc, TQT_SIGNAL( receivedStdout(KProcess*,char*,int) ),
-						         this, TQT_SLOT( checkOutputForPassword( KProcess*,char*,int ) ) );
-						proc.start(KProcess::Block,KProcess::AllOutput);
+						connect( &proc, TQT_SIGNAL( receivedStdout(TDEProcess*,char*,int) ),
+						         this, TQT_SLOT( checkOutputForPassword( TDEProcess*,char*,int ) ) );
+						proc.start(TDEProcess::Block,TDEProcess::AllOutput);
 						encrypted = this->encrypted;
 						
 						if( encrypted )
@@ -1548,7 +1548,7 @@ TQString kio_krarcProtocol::detectArchive( bool &encrypted, TQString fileName )
 	return TQString();
 }
 
-void kio_krarcProtocol::checkOutputForPassword( KProcess *proc,char *buf,int len ) {
+void tdeio_krarcProtocol::checkOutputForPassword( TDEProcess *proc,char *buf,int len ) {
 	TQByteArray d(len);
 	d.setRawData(buf,len);
 	TQString data =  TQString( d );
@@ -1574,13 +1574,13 @@ void kio_krarcProtocol::checkOutputForPassword( KProcess *proc,char *buf,int len
 	}
 }
 
-void kio_krarcProtocol::invalidatePassword() {
+void tdeio_krarcProtocol::invalidatePassword() {
 	KRDEBUG( arcFile->url().path(-1) + "/" );
 	
 	if( !encrypted )
 		return;
 	
-	KIO::AuthInfo authInfo;
+	TDEIO::AuthInfo authInfo;
 	authInfo.caption= i18n( "Krarc Password Dialog" );
 	authInfo.username= "archive";
 	authInfo.readOnly = true;
@@ -1596,7 +1596,7 @@ void kio_krarcProtocol::invalidatePassword() {
 	cacheAuthentication( authInfo );
 }
 
-TQString kio_krarcProtocol::getPassword() {
+TQString tdeio_krarcProtocol::getPassword() {
 	KRDEBUG( encrypted );
 	
 	if( !password.isNull() )
@@ -1604,7 +1604,7 @@ TQString kio_krarcProtocol::getPassword() {
 	if( !encrypted )
 		return (password = "" );
 	
-	KIO::AuthInfo authInfo;
+	TDEIO::AuthInfo authInfo;
 	authInfo.caption= i18n( "Krarc Password Dialog" );
 	authInfo.username= "archive";
 	authInfo.readOnly = true;
@@ -1631,20 +1631,20 @@ TQString kio_krarcProtocol::getPassword() {
 	return password;
 }
 
-TQString kio_krarcProtocol::fullPathName( TQString name ) {
+TQString tdeio_krarcProtocol::fullPathName( TQString name ) {
 	TQString supposedName = krConfig->readEntry( name, name );
 	if( supposedName.isEmpty() )
 		supposedName = name;
 	return escape( supposedName );
 }
 
-TQString kio_krarcProtocol::convertFileName( TQString name ) {
+TQString tdeio_krarcProtocol::convertFileName( TQString name ) {
 	if( arcType == "zip" )
 		name = name.replace( "[", "[[]" );
 	return convertName( name );
 }
 
-TQString kio_krarcProtocol::convertName( TQString name ) {
+TQString tdeio_krarcProtocol::convertName( TQString name ) {
 	if( !name.contains( '\'' ) )
 		return "'" + name + "'";
 	if( !name.contains( '"' ) && !name.contains( '$' ) )
@@ -1652,7 +1652,7 @@ TQString kio_krarcProtocol::convertName( TQString name ) {
 	return escape( name );
 }
 
-TQString kio_krarcProtocol::escape( TQString name ) {    
+TQString tdeio_krarcProtocol::escape( TQString name ) {    
 	const TQString evilstuff = "\\\"'`()[]{}!?;$&<>| ";		// stuff that should get escaped
 	
 	for ( unsigned int i = 0; i < evilstuff.length(); ++i )
