@@ -5,10 +5,10 @@
 #include "../Dialogs/popularurls.h"
 #include "../VFS/vfs.h"
 #include <kiconloader.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <tqptrlist.h>
-#include <kactioncollection.h>
-#include <klocale.h>
+#include <tdeactioncollection.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <kbookmarkmanager.h>
 #include <kstandarddirs.h>
@@ -23,7 +23,7 @@
 											
 KrBookmarkHandler::KrBookmarkHandler(): TQObject(0), _middleClick(false), _mainBookmarkPopup( 0 ), _specialBookmarkIDs(), _bookmarkIDTable() {
 	// create our own action collection and make the shortcuts apply only to parent
-	_privateCollection = new KActionCollection(krApp, "private collection");
+	_privateCollection = new TDEActionCollection(krApp, "private collection");
 	_collection = krApp->actionCollection();
 
 	// create _root: father of all bookmarks. it is a dummy bookmark and never shown
@@ -271,7 +271,7 @@ SUCCESS:
 	file.close();
 }
 
-void KrBookmarkHandler::populate(KPopupMenu *menu) {
+void KrBookmarkHandler::populate(TDEPopupMenu *menu) {
 	_mainBookmarkPopup = menu;
 	menu->clear();
 	_bookmarkIDTable.clear();
@@ -279,15 +279,15 @@ void KrBookmarkHandler::populate(KPopupMenu *menu) {
 	buildMenu(_root, menu);
 }
 
-void KrBookmarkHandler::buildMenu(KrBookmark *parent, KPopupMenu *menu) {
+void KrBookmarkHandler::buildMenu(KrBookmark *parent, TDEPopupMenu *menu) {
 	static int inSecondaryMenu = 0; // used to know if we're on the top menu
 
 	// run the loop twice, in order to put the folders on top. stupid but easy :-)
 	// note: this code drops the separators put there by the user
 	for (KrBookmark *bm = parent->children().first(); bm; bm = parent->children().next()) {
 		if (!bm->isFolder()) continue;
-		KPopupMenu *newMenu = new KPopupMenu(menu);
-		int id = menu->insertItem(TQIconSet(krLoader->loadIcon(bm->icon(), KIcon::Small)),
+		TDEPopupMenu *newMenu = new TDEPopupMenu(menu);
+		int id = menu->insertItem(TQIconSet(krLoader->loadIcon(bm->icon(), TDEIcon::Small)),
 									bm->text(), newMenu, -1 /* dummy id */, -1 /* end of list */);
 		
 		if( !_bookmarkIDTable.find( menu ) )
@@ -327,8 +327,8 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, KPopupMenu *menu) {
 			menu->insertSeparator();
 			
 			// add the popular links submenu
-			KPopupMenu *newMenu = new KPopupMenu(menu);
-			itemIndex = menu->insertItem(TQIconSet(krLoader->loadIcon("bookmark_folder", KIcon::Small)),
+			TDEPopupMenu *newMenu = new TDEPopupMenu(menu);
+			itemIndex = menu->insertItem(TQIconSet(krLoader->loadIcon("bookmark_folder", TDEIcon::Small)),
 										i18n("Popular URLs"), newMenu, -1 /* dummy id */, -1 /* end of list */);
 			_specialBookmarkIDs.append( itemIndex );
 			// add the top 15 urls
@@ -395,10 +395,10 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, KPopupMenu *menu) {
 		if( !hasJumpback )
 			menu->insertSeparator();
 		
-		itemIndex = menu->insertItem(krLoader->loadIcon("bookmark_add", KIcon::Small),
+		itemIndex = menu->insertItem(krLoader->loadIcon("bookmark_add", TDEIcon::Small),
 			i18n("Bookmark Current"), BookmarkCurrent);
 		_specialBookmarkIDs.append( itemIndex );
-		itemIndex = menu->insertItem(krLoader->loadIcon("bookmark", KIcon::Small),
+		itemIndex = menu->insertItem(krLoader->loadIcon("bookmark", TDEIcon::Small),
 			i18n("Manage Bookmarks"), ManageBookmarks);
 		_specialBookmarkIDs.append( itemIndex );
 	
@@ -535,10 +535,10 @@ void KrBookmarkHandler::rightClickOnSpecialBookmark() {
 void KrBookmarkHandler::rightClicked( TQPopupMenu *menu, int /*id*/, KrBookmark * bm ) {
 	TQPopupMenu popup( _mainBookmarkPopup );
 	
-	popup.insertItem( krLoader->loadIcon( "fileopen", KIcon::Panel ), i18n( "Open" ), OPEN_ID );
-	popup.insertItem( krLoader->loadIcon( "tab_new", KIcon::Panel ), i18n( "Open in a new tab" ), OPEN_NEW_TAB_ID );
+	popup.insertItem( krLoader->loadIcon( "document-open", TDEIcon::Panel ), i18n( "Open" ), OPEN_ID );
+	popup.insertItem( krLoader->loadIcon( "tab_new", TDEIcon::Panel ), i18n( "Open in a new tab" ), OPEN_NEW_TAB_ID );
 	popup.insertSeparator();
-	popup.insertItem( krLoader->loadIcon( "editdelete", KIcon::Panel ), i18n( "Delete" ), DELETE_ID );
+	popup.insertItem( krLoader->loadIcon( "edit-delete", TDEIcon::Panel ), i18n( "Delete" ), DELETE_ID );
 	
 	connect( menu, TQT_SIGNAL( highlighted( int ) ), &popup, TQT_SLOT( close() ) );
 	connect( menu, TQT_SIGNAL( activated( int ) ), &popup, TQT_SLOT( close() ) );
@@ -565,7 +565,7 @@ void KrBookmarkHandler::rightClicked( TQPopupMenu *menu, int /*id*/, KrBookmark
 
 // used to monitor middle clicks. if mid is found, then the
 // bookmark is opened in a new tab. ugly, but easier than overloading
-// KAction and KActionCollection.
+// TDEAction and TDEActionCollection.
 void KrBookmarkHandler::slotActivated(const KURL& url) {
 	if (_middleClick)
 		SLOTS->newTab(url);
