@@ -30,12 +30,12 @@
 
 #include <time.h>
 #include <tqlayout.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
 #include <kmimetype.h>
-#include <kmessagebox.h>
-#include <kglobalsettings.h>
-#include <kio/job.h>
+#include <tdemessagebox.h>
+#include <tdeglobalsettings.h>
+#include <tdeio/job.h>
 #include <tqpushbutton.h>
 #include <tqhbox.h>
 #include <tqapplication.h>
@@ -184,7 +184,7 @@ void LoaderWidget::setCurrentURL( KURL url )
   searchedDirectory->setText( vfs::pathOrURL( url, 1) );
 }
 
-void LoaderWidget::setValues( int fileNum, int dirNum, KIO::filesize_t total )
+void LoaderWidget::setValues( int fileNum, int dirNum, TDEIO::filesize_t total )
 {
   files->setText( TQString("%1").arg( fileNum ) );
   directories->setText( TQString("%1").arg( dirNum ) );
@@ -475,7 +475,7 @@ int DiskUsage::calculateSizes( Directory *dirEntry, bool emitSig, int depth )
   if( dirEntry == 0 )
     dirEntry = root;
 
-  KIO::filesize_t own = 0, total = 0;
+  TDEIO::filesize_t own = 0, total = 0;
 
   for( Iterator<File> it = dirEntry->iterator(); it != dirEntry->end(); ++it )
   {
@@ -492,7 +492,7 @@ int DiskUsage::calculateSizes( Directory *dirEntry, bool emitSig, int depth )
     }
   }
 
-  KIO::filesize_t oldOwn = dirEntry->ownSize(), oldTotal = dirEntry->size();
+  TDEIO::filesize_t oldOwn = dirEntry->ownSize(), oldTotal = dirEntry->size();
   dirEntry->setSizes( total, own );
 
   if( dirEntry == currentDirectory )
@@ -637,20 +637,20 @@ int DiskUsage::del( File *file, bool calcPercents, int depth )
   emit deleted( file );
   deleteNr++;
 
-  TQGuardedPtr<KIO::Job> job;
+  TQGuardedPtr<TDEIO::Job> job;
 
   if( trash )
   {
 #if KDE_IS_VERSION(3,4,0)
-    job = KIO::trash( url, true );
+    job = TDEIO::trash( url, true );
 #else
-    job = new KIO::CopyJob( url,KGlobalSettings::trashPath(),KIO::CopyJob::Move,false,true );
+    job = new TDEIO::CopyJob( url,TDEGlobalSettings::trashPath(),TDEIO::CopyJob::Move,false,true );
 #endif
-    connect(job,TQT_SIGNAL(result(KIO::Job*)),krApp,TQT_SLOT(changeTrashIcon()));
+    connect(job,TQT_SIGNAL(result(TDEIO::Job*)),krApp,TQT_SLOT(changeTrashIcon()));
   }
   else
   {
-    job = new KIO::DeleteJob( vfs::fromPathOrURL( file->fullPath() ), false, false);
+    job = new TDEIO::DeleteJob( vfs::fromPathOrURL( file->fullPath() ), false, false);
   }
 
   deleting = true;    // during tqApp->processEvent strange things can occur
@@ -746,9 +746,9 @@ Directory* DiskUsage::getCurrentDir()
   return currentDirectory;
 }
 
-void DiskUsage::rightClickMenu( File *fileItem, KPopupMenu *addPopup, TQString addPopupName )
+void DiskUsage::rightClickMenu( File *fileItem, TDEPopupMenu *addPopup, TQString addPopupName )
 {
-  KPopupMenu popup( this );
+  TDEPopupMenu popup( this );
 
   popup.insertTitle( i18n("Disk Usage"));
 
@@ -780,7 +780,7 @@ void DiskUsage::rightClickMenu( File *fileItem, KPopupMenu *addPopup, TQString a
     popup.changeItem( ADDITIONAL_POPUP_ID, addPopupName );
   }
 
-  KPopupMenu viewPopup;
+  TDEPopupMenu viewPopup;
   viewPopup.insertItem(i18n("Lines"),      LINES_VIEW_ID);
   viewPopup.setAccel( CTRL + Key_L, LINES_VIEW_ID );
   viewPopup.insertItem(i18n("Detailed"),   DETAILED_VIEW_ID);
@@ -1025,7 +1025,7 @@ TQString DiskUsage::getToolTip( File *item )
   time_t tma = item->time();
   struct tm* t=localtime((time_t *)&tma);
   TQDateTime tmp(TQDate(t->tm_year+1900, t->tm_mon+1, t->tm_mday), TQTime(t->tm_hour, t->tm_min));
-  TQString date = KGlobal::locale()->formatDateTime(tmp);
+  TQString date = TDEGlobal::locale()->formatDateTime(tmp);
 
   TQString str = "<qt><h5><table><tr><td>" + i18n( "Name:" ) +  "</td><td>" + item->name() + "</td></tr>"+
                 "<tr><td>" + i18n( "Type:" ) +  "</td><td>" + mime + "</td></tr>"+
