@@ -31,14 +31,14 @@
 #include <tqtextstream.h> 
 // KDE includes
 #include <kprocess.h>
-#include <ktempfile.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kio/passdlg.h> 
+#include <tdetempfile.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeio/passdlg.h> 
 #include <tqfile.h>
 #include <kstandarddirs.h>
 #include <ktar.h>
-#include <kio/global.h>
+#include <tdeio/global.h>
 // Krusader includes
 #include "krarchandler.h"
 #include "../krusader.h"
@@ -48,7 +48,7 @@
 
 static TQStringList arcProtocols = TQStringList::split(";", "tar;bzip;bzip2;gzip;krarc;zip");
 
-KWallet::Wallet * KRarcHandler::wallet = 0;
+TDEWallet::Wallet * KRarcHandler::wallet = 0;
 
 TQStringList KRarcHandler::supportedPackers() {
   TQStringList packers;
@@ -190,7 +190,7 @@ long KRarcHandler::arcFileCount( TQString archive, TQString type, TQString passw
   list << lister << KrServices::quote( archive ) << ">" << tmpFile.name() ;
   if( type == "-ace" && TQFile( "/dev/ptmx" ).exists() )  // Don't remove, unace crashes if missing!!!
     list<< "<" << "/dev/ptmx";
-  list.start( KProcess::NotifyOnExit, KProcess::AllOutput );
+  list.start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
   while ( list.isRunning() ) {
     usleep( 1000 );
     tqApp->processEvents();
@@ -257,7 +257,7 @@ bool KRarcHandler::unpack( TQString archive, TQString type, TQString password, T
 
     KrShellProcess cpio;
     cpio << KrServices::fullPathName( "rpm2cpio" ) << " " + KrServices::quote( archive ) << " > " << cpioName;
-    cpio.start(KProcess::Block, KProcess::AllOutput );
+    cpio.start(TDEProcess::Block, TDEProcess::AllOutput );
     if( !cpio.normalExit() || !checkStatus( "cpio", cpio.exitStatus() ) ) {
       KMessageBox::detailedError (krApp, i18n( "Failed to convert rpm (%1) to cpio!" ).arg( archive ), 
                                   cpio.getErrorMsg(), i18n("Error" ) );
@@ -274,7 +274,7 @@ bool KRarcHandler::unpack( TQString archive, TQString type, TQString password, T
 
     KrShellProcess dpkg;
     dpkg << KrServices::fullPathName( "dpkg" ) << " --fsys-tarfile " + KrServices::quote( archive ) << " > " << cpioName;
-    dpkg.start(KProcess::Block, KProcess::AllOutput );
+    dpkg.start(TDEProcess::Block, TDEProcess::AllOutput );
     if( !dpkg.normalExit() || !checkStatus( "-deb", dpkg.exitStatus() ) ) {
       KMessageBox::detailedError (krApp, i18n( "Failed to convert deb (%1) to tar!" ).arg( archive ), 
                                   dpkg.getErrorMsg(), i18n("Error" ) );
@@ -312,15 +312,15 @@ bool KRarcHandler::unpack( TQString archive, TQString type, TQString password, T
   // tell the user to wait
   krApp->startWaiting( i18n( "Unpacking File(s)" ), count, true );
   if ( count != 0 ) {
-    connect( &proc, TQT_SIGNAL( receivedStdout( KProcess*, char*, int ) ),
-             krApp, TQT_SLOT( incProgress( KProcess*, char*, int ) ) );
+    connect( &proc, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ),
+             krApp, TQT_SLOT( incProgress( TDEProcess*, char*, int ) ) );
     if( type == "-rpm" )
-      connect( &proc, TQT_SIGNAL( receivedStderr( KProcess*, char*, int ) ),
-               krApp, TQT_SLOT( incProgress( KProcess*, char*, int ) ) );
+      connect( &proc, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ),
+               krApp, TQT_SLOT( incProgress( TDEProcess*, char*, int ) ) );
   }
 
   // start the unpacking process
-  proc.start( KProcess::NotifyOnExit, KProcess::AllOutput );
+  proc.start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
   while ( proc.isRunning() ) {
     usleep( 1000 );
     tqApp->processEvents();
@@ -382,11 +382,11 @@ bool KRarcHandler::test( TQString archive, TQString type, TQString password, lon
   
   // tell the user to wait
   krApp->startWaiting( i18n( "Testing Archive" ), count, true );
-  if ( count != 0 ) connect( &proc, TQT_SIGNAL( receivedStdout( KProcess*, char*, int ) ),
-                               krApp, TQT_SLOT( incProgress( KProcess*, char*, int ) ) );
+  if ( count != 0 ) connect( &proc, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ),
+                               krApp, TQT_SLOT( incProgress( TDEProcess*, char*, int ) ) );
 
   // start the unpacking process
-  proc.start( KProcess::NotifyOnExit, KProcess::AllOutput );
+  proc.start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
   while ( proc.isRunning() ) {
     usleep( 1000 );
     tqApp->processEvents();
@@ -442,7 +442,7 @@ bool KRarcHandler::pack( TQStringList fileNames, TQString type, TQString dest, l
 
   if( extraProps.count( "VolumeSize" ) > 0 ) {
      TQString sizeStr = extraProps[ "VolumeSize" ];
-     KIO::filesize_t size = sizeStr.toLongLong();
+     TDEIO::filesize_t size = sizeStr.toLongLong();
 
      if( size >= 10000 ) {
        if( type == "-arj" || type == "-rar" )
@@ -489,11 +489,11 @@ bool KRarcHandler::pack( TQStringList fileNames, TQString type, TQString dest, l
   // tell the user to wait
   krApp->startWaiting( i18n( "Packing File(s)" ), count, true );
   if ( count != 0 )
-    connect( &proc, TQT_SIGNAL( receivedStdout( KProcess*, char*, int ) ),
-             krApp, TQT_SLOT( incProgress( KProcess*, char*, int ) ) );
+    connect( &proc, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ),
+             krApp, TQT_SLOT( incProgress( TDEProcess*, char*, int ) ) );
 
   // start the packing process
-  proc.start( KProcess::NotifyOnExit, KProcess::AllOutput );
+  proc.start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
   while ( proc.isRunning() ) {
     usleep( 1000 );
     tqApp->processEvents();
@@ -525,15 +525,15 @@ TQString KRarcHandler::getPassword( TQString path ) {
 	
 	TQString key = "krarc-" + path;
 	
-	if( !KWallet::Wallet::keyDoesNotExist(KWallet::Wallet::NetworkWallet(), KWallet::Wallet::PasswordFolder(), key ) ) {
-		if( !KWallet::Wallet::isOpen( KWallet::Wallet::NetworkWallet() )  && wallet != 0 ) {
+	if( !TDEWallet::Wallet::keyDoesNotExist(TDEWallet::Wallet::NetworkWallet(), TDEWallet::Wallet::PasswordFolder(), key ) ) {
+		if( !TDEWallet::Wallet::isOpen( TDEWallet::Wallet::NetworkWallet() )  && wallet != 0 ) {
 			delete wallet;
 			wallet = 0;
 		}
 		if( wallet == 0 )
-			wallet = KWallet::Wallet::openWallet( KWallet::Wallet::NetworkWallet() );
-		if ( wallet && wallet->hasFolder( KWallet::Wallet::PasswordFolder() ) ) {
-			wallet->setFolder( KWallet::Wallet::PasswordFolder() );
+			wallet = TDEWallet::Wallet::openWallet( TDEWallet::Wallet::NetworkWallet() );
+		if ( wallet && wallet->hasFolder( TDEWallet::Wallet::PasswordFolder() ) ) {
+			wallet->setFolder( TDEWallet::Wallet::PasswordFolder() );
 			TQMap<TQString,TQString> map;
 			if ( wallet->readMap( key, map ) == 0 ) {
 				TQMap<TQString, TQString>::ConstIterator it = map.find( "password" );
@@ -545,24 +545,24 @@ TQString KRarcHandler::getPassword( TQString path ) {
 	
 	bool keep = true;
 	TQString user = "archive";
-	KIO::PasswordDialog passDlg( i18n("This archive is encrypted, please supply the password:"),
+	TDEIO::PasswordDialog passDlg( i18n("This archive is encrypted, please supply the password:"),
 	                             user, true );
 	passDlg.setPassword( password );
-	if (passDlg.exec() == KIO::PasswordDialog::Accepted) {
+	if (passDlg.exec() == TDEIO::PasswordDialog::Accepted) {
 		password = passDlg.password();
 		if ( keep ) {
-			if( !KWallet::Wallet::isOpen( KWallet::Wallet::NetworkWallet() ) && wallet != 0 ) {
+			if( !TDEWallet::Wallet::isOpen( TDEWallet::Wallet::NetworkWallet() ) && wallet != 0 ) {
 				delete wallet;
 				wallet = 0;
 			}
 			if ( !wallet )
-				wallet = KWallet::Wallet::openWallet( KWallet::Wallet::NetworkWallet() );
+				wallet = TDEWallet::Wallet::openWallet( TDEWallet::Wallet::NetworkWallet() );
 			if ( wallet ) {
 				bool ok = true;
-				if ( !wallet->hasFolder( KWallet::Wallet::PasswordFolder() ) )
-					ok = wallet->createFolder( KWallet::Wallet::PasswordFolder() );
+				if ( !wallet->hasFolder( TDEWallet::Wallet::PasswordFolder() ) )
+					ok = wallet->createFolder( TDEWallet::Wallet::PasswordFolder() );
 				if ( ok ) {
-					wallet->setFolder( KWallet::Wallet::PasswordFolder() );
+					wallet->setFolder( TDEWallet::Wallet::PasswordFolder() );
 					TQMap<TQString,TQString> map;
 					map.insert( "login", "archive" );
 					map.insert( "password", password );
@@ -722,7 +722,7 @@ TQString KRarcHandler::detectArchive( bool &encrypted, TQString fileName, bool c
 						Kr7zEncryptionChecker proc;
 						proc << KrServices::fullPathName( "7z" ) << " -y t";
 						proc << KrServices::quote( fileName );
-						proc.start(KProcess::Block,KProcess::AllOutput);
+						proc.start(TDEProcess::Block,TDEProcess::AllOutput);
 						encrypted = proc.isEncrypted();
 					}
 				}
